@@ -2,12 +2,16 @@
 This file contains celery tasks for email marketing signal handler.
 """
 
+from __future__ import absolute_import
 from decimal import Decimal
 
 from celery import shared_task
 from celery.utils.log import get_task_logger
 from sailthru.sailthru_error import SailthruClientError
 
+from requests.exceptions import RequestException
+from six import text_type
+
 from ecommerce_worker.cache import Cache
 from ecommerce_worker.sailthru.v1.exceptions import SailthruError
 from ecommerce_worker.sailthru.v1.notification import Notification
@@ -17,8 +21,6 @@ from ecommerce_worker.sailthru.v1.utils import (
     get_sailthru_configuration
 )
 from ecommerce_worker.utils import get_ecommerce_client
-from requests.exceptions import RequestException
-from six import text_type
 
 logger = get_task_logger(__name__)  # pylint: disable=invalid-name
 cache = Cache()  # pylint: disable=invalid-name
@@ -256,7 +258,7 @@ def update_course_enrollment(self, email, course_url, purchase_incomplete, mode,
         if mode == 'verified':
             # upgrade complete
             send_template = config.get('SAILTHRU_UPGRADE_TEMPLATE')
-        elif mode == 'audit' or mode == 'honor':
+        elif mode in ('audit', 'honor'):
             # free enroll
             new_enroll = True
             send_template = config.get('SAILTHRU_ENROLL_TEMPLATE')
@@ -360,7 +362,8 @@ def send_course_refund_email(self, email, refund_id, amount, course_name, order_
 
 
 @shared_task(bind=True, ignore_result=True)
-def send_offer_assignment_email(self, user_email, offer_assignment_id, subject, email_body, site_code=None):
+def send_offer_assignment_email(self, user_email, offer_assignment_id, subject, email_body,
+                                site_code=None, base_enterprise_url=''):
     """
     Sends the offer assignment email.
 
@@ -371,6 +374,7 @@ def send_offer_assignment_email(self, user_email, offer_assignment_id, subject,
         subject (str): Email subject.
         email_body (str): The body of the email.
         site_code (str): Identifier of the site sending the email.
+        base_enterprise_url (str): Url for the enterprise learner portal.
     """
     config = get_sailthru_configuration(site_code)
     notification = Notification(
@@ -378,9 +382,10 @@ def send_offer_assignment_email(self, user_email, offer_assignment_id, subject,
         emails=user_email,
         email_vars={
             'subject': subject,
-            'email_body': email_body
+            'email_body': email_body,
+            'base_enterprise_url': base_enterprise_url,
         },
-        logger_prefix="Offer Assignment",
+        logger_prefix='Offer Assignment',
         site_code=site_code,
         template='enterprise_portal_email'
     )
@@ -391,8 +396,10 @@ def send_offer_assignment_email(self, user_email, offer_assignment_id, subject,
     if response and response.is_ok():
         send_id = response.get_body().get('send_id')  # pylint: disable=no-member
         if _update_assignment_email_status(offer_assignment_id, send_id, 'success'):
-            logger.info('[Offer Assignment] Offer assignment notification sent with message --- {message}'.format(
-                message=email_body))
+            logger.info('[Offer Assignment] Offer assignment notification sent with message --- '
+                        '{message}; base enterprise url --- {base_enterprise_url}'.format(
+                            message=email_body,
+                            base_enterprise_url=base_enterprise_url))
         else:
             logger.exception(
                 '[Offer Assignment] An error occurred while updating email status data for '
@@ -431,7 +438,7 @@ def _update_assignment_email_status(offer_assignment_id, send_id, status, site_c
             )
         )
         return False
-    return True if api_response.get('status') == 'updated' else False
+    return bool(api_response.get('status') == 'updated')
 
 
 @shared_task(bind=True, ignore_result=True)
@@ -454,7 +461,7 @@ def send_offer_update_email(self, user_email, subject, email_body, site_code=Non
             'subject': subject,
             'email_body': email_body
         },
-        logger_prefix="Offer Assignment",
+        logger_prefix='Offer Assignment',
         site_code=site_code,
         template='enterprise_portal_email'
     )
@@ -483,10 +490,39 @@ def send_offer_usage_email(self, emails, subject, email_body, site_code=None):
             'subject': subject,
             'email_body': email_body
         },
-        logger_prefix="Offer Usage",
+        logger_prefix='Offer Usage',
         site_code=site_code,
         template='assignment_email'
     )
     _, is_eligible_for_retry = notification.send(is_multi_send=True)
     if is_eligible_for_retry:
         schedule_retry(self, config)
+
+
+@shared_task(bind=True, ignore_result=True)
+def send_code_assignment_nudge_email(self, email, subject, email_body, site_code=None):
+    """
+    Sends the code assignment nudge email.
+
+    Args:
+        self: Ignore.
+        email (str): Recipient's email address.
+        subject (str): Email subject.
+        email_body (str): The body of the email.
+        site_code (str): Identifier of the site sending the email.
+    """
+    config = get_sailthru_configuration(site_code)
+    notification = Notification(
+        config=config,
+        emails=email,
+        email_vars={
+            'subject': subject,
+            'email_body': email_body
+        },
+        logger_prefix='Code Assignment Nudge Email',
+        site_code=site_code,
+        template='enterprise_portal_email'
+    )
+    _, is_eligible_for_retry = notification.send()
+    if is_eligible_for_retry:
+        schedule_retry(self, config)
