@@ -1,11 +1,12 @@
 """Tests of Sailthru worker code."""
+from __future__ import absolute_import, unicode_literals
 import logging
 import json
 from decimal import Decimal
 from unittest import TestCase
 import ddt
 
-import httpretty
+import responses
 from celery.exceptions import Retry
 from mock import patch, Mock
 from sailthru import SailthruClient
@@ -15,17 +16,23 @@ from requests.exceptions import RequestException
 from six import text_type
 from ecommerce_worker.sailthru.v1.exceptions import SailthruError
 from ecommerce_worker.sailthru.v1.tasks import (
-    update_course_enrollment, _update_unenrolled_list, _get_course_content, _get_course_content_from_ecommerce,
-    send_course_refund_email, send_offer_assignment_email, send_offer_update_email, send_offer_usage_email,
     _update_assignment_email_status,
-
+    _update_unenrolled_list,
+    _get_course_content,
+    _get_course_content_from_ecommerce,
+    send_code_assignment_nudge_email,
+    send_course_refund_email,
+    send_offer_assignment_email,
+    send_offer_update_email,
+    send_offer_usage_email,
+    update_course_enrollment,
 )
 from ecommerce_worker.utils import get_configuration
 
 TEST_EMAIL = "test@edx.org"
 
 
-class MockSailthruResponse(object):
+class MockSailthruResponse:
     """
     Mock object for SailthruResponse
     """
@@ -48,7 +55,7 @@ class MockSailthruResponse(object):
         return MockSailthruError(self.error, self.code)
 
 
-class MockSailthruError(object):
+class MockSailthruError:
     """
     Mock object for Sailthru Error
     """
@@ -84,9 +91,9 @@ class SailthruTests(TestCase):
 
     def mock_ecommerce_api(self, body, course_id, status=200):
         """ Mock GET requests to the ecommerce course API endpoint. """
-        httpretty.reset()
-        httpretty.register_uri(
-            httpretty.GET, '{}/courses/{}/'.format(
+        responses.reset()
+        responses.add(
+            responses.GET, '{}/courses/{}/'.format(
                 get_configuration('ECOMMERCE_API_ROOT').strip('/'), text_type(course_id)
             ),
             status=status,
@@ -420,7 +427,7 @@ class SailthruTests(TestCase):
         )
         self.assertTrue(mock_log_error.called)
 
-    @httpretty.activate
+    @responses.activate
     @patch('ecommerce_worker.sailthru.v1.utils.SailthruClient')
     def test_get_course_content(self, mock_sailthru_client):
         """
@@ -429,13 +436,13 @@ class SailthruTests(TestCase):
         config = {'SAILTHRU_CACHE_TTL_SECONDS': 100}
         mock_sailthru_client.api_get.return_value = MockSailthruResponse({"title": "The title"})
         response_json = _get_course_content(self.course_id, 'course:123', mock_sailthru_client, None, config)
-        self.assertEquals(response_json, {"title": "The title"})
+        self.assertEqual(response_json, {"title": "The title"})
         mock_sailthru_client.api_get.assert_called_with('content', {'id': 'course:123'})
 
         # test second call uses cache
         mock_sailthru_client.reset_mock()
         response_json = _get_course_content(self.course_id, 'course:123', mock_sailthru_client, None, config)
-        self.assertEquals(response_json, {"title": "The title"})
+        self.assertEqual(response_json, {"title": "The title"})
         mock_sailthru_client.api_get.assert_not_called()
 
         # test error from Sailthru
@@ -446,7 +453,7 @@ class SailthruTests(TestCase):
             'verification_deadline': '2016-12-01T23:59:00Z'
         }
         self.mock_ecommerce_api(data, self.course_id)
-        self.assertEquals(
+        self.assertEqual(
             _get_course_content(self.course_id, 'course:124', mock_sailthru_client, None, config), expected_response
         )
 
@@ -458,18 +465,18 @@ class SailthruTests(TestCase):
         }
         mock_sailthru_client.api_get.side_effect = SailthruClientError
         self.mock_ecommerce_api(data, self.course_id)
-        self.assertEquals(
+        self.assertEqual(
             _get_course_content(self.course_id, 'course:125', mock_sailthru_client, None, config), expected_response
         )
 
         # test Sailthru and Ecommerce exception
         mock_sailthru_client.api_get.side_effect = SailthruClientError
         self.mock_ecommerce_api({}, self.course_id2, status=500)
-        self.assertEquals(
+        self.assertEqual(
             _get_course_content(self.course_id2, 'course:126', mock_sailthru_client, None, config), {}
         )
 
-    @httpretty.activate
+    @responses.activate
     def test_get_course_content_from_ecommerce(self):
         """
         Test routine that fetches data from ecommerce.
@@ -482,12 +489,12 @@ class SailthruTests(TestCase):
         self.mock_ecommerce_api(data, self.course_id)
 
         response_json = _get_course_content_from_ecommerce(self.course_id, None)
-        self.assertEquals(response_json, expected_response)
+        self.assertEqual(response_json, expected_response)
 
         # test error getting data
         self.mock_ecommerce_api({}, self.course_id2, status=500)
         response_json = _get_course_content_from_ecommerce(self.course_id2, None)
-        self.assertEquals(response_json, {})
+        self.assertEqual(response_json, {})
 
     @patch('ecommerce_worker.sailthru.v1.utils.SailthruClient')
     def test_update_unenrolled_list_new(self, mock_sailthru_client):
@@ -574,8 +581,8 @@ class SendCourseRefundEmailTests(TestCase):
 
     def mock_api_response(self, status, body):
         """ Mock the Sailthru send API. """
-        httpretty.register_uri(
-            httpretty.POST,
+        responses.add(
+            responses.POST,
             'https://api.sailthru.com/send',
             status=status,
             body=json.dumps(body),
@@ -598,7 +605,7 @@ class SendCourseRefundEmailTests(TestCase):
             self.REFUND_ID
         )
 
-    @httpretty.activate
+    @responses.activate
     def test_api_error_with_retry(self):
         """ Verify the task is rescheduled if an API error occurs, and the request can be retried. """
         error_code = 43
@@ -621,7 +628,7 @@ class SendCourseRefundEmailTests(TestCase):
              'An attempt will be made again to send a course refund notification for refund [%d].' % self.REFUND_ID),
         )
 
-    @httpretty.activate
+    @responses.activate
     def test_api_error_without_retry(self):
         """ Verify error details are logged if an API error occurs, and the request can NOT be retried. """
         error_code = 1
@@ -643,7 +650,7 @@ class SendCourseRefundEmailTests(TestCase):
              'No further attempts will be made to send a course refund notification for refund [%d].' % self.REFUND_ID),
         )
 
-    @httpretty.activate
+    @responses.activate
     def test_message_sent(self):
         """ Verify a message is logged after a successful API call to send the message. """
         self.mock_api_response(200, {'send_id': '1234ABC'})
@@ -662,8 +669,8 @@ class BaseSendEmailTests(TestCase):
 
     def mock_api_response(self, status, body):
         """ Mock the Sailthru send API. """
-        httpretty.register_uri(
-            httpretty.POST,
+        responses.add(
+            responses.POST,
             'https://api.sailthru.com/send',
             status=status,
             body=json.dumps(body),
@@ -683,12 +690,14 @@ class SendOfferEmailsTests(BaseSendEmailTests):
     SUBJECT = 'New edX course assignment'
     EMAIL_BODY = 'Template message with johndoe@unknown.com GIL7RUEOU7VHBH7Q ' \
                  'http://tempurl.url/enroll 3 2012-04-23'
+    BASE_ENTERPRISE_URL = 'https://bears.party'
 
     ASSIGNMENT_TASK_KWARGS = {
         'user_email': USER_EMAIL,
         'offer_assignment_id': OFFER_ASSIGNMENT_ID,
         'subject': SUBJECT,
         'email_body': EMAIL_BODY,
+        'base_enterprise_url': BASE_ENTERPRISE_URL,
     }
 
     UPDATE_TASK_KWARGS = {
@@ -703,15 +712,21 @@ class SendOfferEmailsTests(BaseSendEmailTests):
         'email_body': EMAIL_BODY,
     }
 
+    NUDGE_TASK_KWARGS = {
+        'email': USER_EMAIL,
+        'subject': SUBJECT,
+        'email_body': EMAIL_BODY,
+    }
+
     def execute_task(self):
         """ Execute the send_offer_assignment_email task. """
         send_offer_assignment_email(**self.ASSIGNMENT_TASK_KWARGS)
 
     def mock_ecommerce_assignmentemail_api(self, body, status=200):
         """ Mock POST requests to the ecommerce assignmentemail API endpoint. """
-        httpretty.reset()
-        httpretty.register_uri(
-            httpretty.POST, '{}/assignment-email/status/'.format(
+        responses.reset()
+        responses.add(
+            responses.POST, '{}/assignment-email/status/'.format(
                 get_configuration('ECOMMERCE_API_ROOT').strip('/')
             ),
             status=status,
@@ -723,6 +738,7 @@ class SendOfferEmailsTests(BaseSendEmailTests):
         (send_offer_assignment_email, ASSIGNMENT_TASK_KWARGS, "Offer Assignment"),
         (send_offer_update_email, UPDATE_TASK_KWARGS, "Offer Assignment"),
         (send_offer_usage_email, USAGE_TASK_KWARGS, "Offer Usage"),
+        (send_code_assignment_nudge_email, NUDGE_TASK_KWARGS, "Code Assignment Nudge Email"),
     )
     @ddt.unpack
     def test_client_instantiation_error(self, task, task_kwargs, logger_prefix):
@@ -746,6 +762,7 @@ class SendOfferEmailsTests(BaseSendEmailTests):
         (send_offer_assignment_email, ASSIGNMENT_TASK_KWARGS, "send", "Offer Assignment"),
         (send_offer_update_email, UPDATE_TASK_KWARGS, "send", "Offer Assignment"),
         (send_offer_usage_email, USAGE_TASK_KWARGS, "multi_send", "Offer Usage"),
+        (send_code_assignment_nudge_email, NUDGE_TASK_KWARGS, "send", "Code Assignment Nudge Email"),
     )
     @ddt.unpack
     def test_api_client_error(self, task, task_kwargs, mock_send, logger_prefix, mock_log):
@@ -760,11 +777,12 @@ class SendOfferEmailsTests(BaseSendEmailTests):
             )
         )
 
-    @httpretty.activate
+    @responses.activate
     @ddt.data(
         (send_offer_assignment_email, ASSIGNMENT_TASK_KWARGS, "Offer Assignment"),
         (send_offer_update_email, UPDATE_TASK_KWARGS, "Offer Assignment"),
         (send_offer_usage_email, USAGE_TASK_KWARGS, "Offer Usage"),
+        (send_code_assignment_nudge_email, NUDGE_TASK_KWARGS, "Code Assignment Nudge Email"),
     )
     @ddt.unpack
     def test_api_error_with_retry(self, task, task_kwargs, logger_prefix):
@@ -801,11 +819,12 @@ class SendOfferEmailsTests(BaseSendEmailTests):
             ),
         )
 
-    @httpretty.activate
+    @responses.activate
     @ddt.data(
         (send_offer_assignment_email, ASSIGNMENT_TASK_KWARGS, "Offer Assignment"),
         (send_offer_update_email, UPDATE_TASK_KWARGS, "Offer Assignment"),
         (send_offer_usage_email, USAGE_TASK_KWARGS, "Offer Usage"),
+        (send_code_assignment_nudge_email, NUDGE_TASK_KWARGS, "Code Assignment Nudge Email"),
     )
     @ddt.unpack
     def test_api_error_without_retry(self, task, task_kwargs, logger_prefix):
@@ -843,10 +862,11 @@ class SendOfferEmailsTests(BaseSendEmailTests):
             ),
         )
 
-    @httpretty.activate
+    @responses.activate
     @ddt.data(
         (send_offer_update_email, UPDATE_TASK_KWARGS, "Offer Assignment"),
         (send_offer_usage_email, USAGE_TASK_KWARGS, "Offer Usage"),
+        (send_code_assignment_nudge_email, NUDGE_TASK_KWARGS, "Code Assignment Nudge Email"),
     )
     @ddt.unpack
     def test_api(self, task, task_kwargs, logger_prefix):
@@ -870,7 +890,7 @@ class SendOfferEmailsTests(BaseSendEmailTests):
             )
         )
 
-    @httpretty.activate
+    @responses.activate
     @patch('ecommerce_worker.sailthru.v1.tasks._update_assignment_email_status')
     def test_message_sent(self, mock_update_assignment):
         """ Verify a message is logged after a successful API call to send the message. """
@@ -888,14 +908,16 @@ class SendOfferEmailsTests(BaseSendEmailTests):
             (
                 self.LOG_TASK_NAME,
                 'INFO',
-                '[Offer Assignment] Offer assignment notification sent with message --- {message}'.format(
-                    message=self.EMAIL_BODY
+                '[Offer Assignment] Offer assignment notification sent with message --- '
+                '{message}; base enterprise url --- {base_enterprise_url}'.format(
+                    message=self.EMAIL_BODY,
+                    base_enterprise_url=self.BASE_ENTERPRISE_URL
                 )
             ),
         )
         self.assertEqual(mock_update_assignment.call_count, 1)
 
-    @httpretty.activate
+    @responses.activate
     @patch('ecommerce_worker.utils.get_ecommerce_client')
     def test_update_assignment_exception(self, mock_get_ecommerce_client):
         """ Verify a message is logged after an unsuccessful API call to update the status. """
@@ -931,7 +953,7 @@ class SendOfferEmailsTests(BaseSendEmailTests):
             )
         )
 
-    @httpretty.activate
+    @responses.activate
     @ddt.data(
         (
             # Success case
